==> react-native-common-ui-0.1.3.tgz: package/js/Basics/CheckBox.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import { Path, Svg } from 'react-native-svg';
const Checked = (props) => {
    return (React.createElement(Svg, { width: props.width, height: props.height, style: props.style, viewBox: '0 0 24 24' },
        React.createElement(Path, { d: 'M19 3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.11 0 2-.9 2-2V5c0-1.1-.89-2-2-2zm-9 14l-5-5 1.41-1.41L10 14.17l7.59-7.59L19 8l-9 9z', fill: props.color })));
};
const Unchecked = (props) => {
    return (React.createElement(Svg, { width: props.width, height: props.height, style: props.style, viewBox: '0 0 24 24' },
        React.createElement(Path, { d: 'M19 5v14H5V5h14m0-2H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2z', fill: props.color })));
};
const Intermediate = (props) => {
    return (React.createElement(Svg, { width: props.width, height: props.height, style: props.style, viewBox: '0 0 24 24' },
        React.createElement(Path, { d: 'M19 3H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-2 10H7v-2h10v2z', fill: props.color })));
};
export const CheckBox = (props) => {
    const { checked } = props, others = __rest(props, ["checked"]);
    if (checked === undefined) {
        return React.createElement(Intermediate, Object.assign({}, others));
    }
    return checked ? React.createElement(Checked, Object.assign({}, others)) : React.createElement(Unchecked, Object.assign({}, others));
};

==> react-native-common-ui-0.1.7.tgz: package/js/Basics/CheckBox.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import { Path, Svg } from 'react-native-svg';
const Checked = (props) => {
    return (React.createElement(Svg, { width: props.width, height: props.height, style: props.style, viewBox: '0 0 24 24' },
        React.createElement(Path, { d: 'M19 3H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-8.29 13.29c-.39.39-1.02.39-1.41 0L5.71 12.7c-.39-.39-.39-1.02 0-1.41.39-.39 1.02-.39 1.41 0L10 14.17l6.88-6.88c.39-.39 1.02-.39 1.41 0 .39.39.39 1.02 0 1.41l-7.58 7.59z', fill: props.color })));
};
const Unchecked = (props) => {
    return (React.createElement(Svg, { width: props.width, height: props.height, style: props.style, viewBox: '0 0 24 24' },
        React.createElement(Path, { d: 'M18 19H6c-.55 0-1-.45-1-1V6c0-.55.45-1 1-1h12c.55 0 1 .45 1 1v12c0 .55-.45 1-1 1zm1-16H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2z', fill: props.color })));
};
const Intermediate = (props) => {
    return (React.createElement(Svg, { width: props.width, height: props.height, style: props.style, viewBox: '0 0 24 24' },
        React.createElement(Path, { d: 'M19 3H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-3 10H8c-.55 0-1-.45-1-1s.45-1 1-1h8c.55 0 1 .45 1 1s-.45 1-1 1z', fill: props.color })));
};
export const CheckBox = (props) => {
    const { checked } = props, others = __rest(props, ["checked"]);
    if (checked === undefined) {
        return React.createElement(Intermediate, Object.assign({}, others));
    }
    return checked ? React.createElement(Checked, Object.assign({}, others)) : React.createElement(Unchecked, Object.assign({}, others));
};
